package aliyun

import (
	"applet/app/db"
	"applet/app/e"
	"applet/app/enum"
	md "applet/app/md/setCenter/oss/aliyun"
	"applet/app/utils/cache"
	"code.fnuoos.com/EggPlanet/egg_models.git/src/implement"
	"github.com/gin-gonic/gin"
)

// GetBasic
// @Summary      设置中心-对象存储-对象存储设置(获取)
// @Tags         对象存储
// @Description  对象存储设置(获取)
// @Accept       json
// @Produce      json
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Success      200   {object}  	md.GetBasicResp "设置列表"
// @Failure      400   {object}   md.Response              	"具体错误"
// @Router       /api/comm/oss/getOssUrl [get]
func GetBasic(c *gin.Context) {
	redisConn := cache.GetPool().Get()
	sysCfgDb := implement.NewSysCfgDb(db.Db, redisConn)
	sysCfg, err := sysCfgDb.SysCfgGetAll()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	cfgMap := make(map[string]string, len(*sysCfg))
	for _, cfg := range *sysCfg {
		cfgMap[cfg.Key] = cfg.Val
	}
	endpoint, ok := cfgMap[enum.AliyunOss(enum.AliyunOssEndpoint).String()]
	if !ok {
		sysCfgDb.SysCfgInsert(enum.AliyunOss(enum.AliyunOssEndpoint).String(), "", "oss地域节点")
		endpoint = ""
	}
	bucketName, ok := cfgMap[enum.AliyunOss(enum.AliyunOssBucketName).String()]
	if !ok {
		sysCfgDb.SysCfgInsert(enum.AliyunOss(enum.AliyunOssBucketName).String(), "", "oss存储桶名称")
		bucketName = ""
	}
	bucketScheme, ok := cfgMap[enum.AliyunOss(enum.AliyunOssBucketScheme).String()]
	if !ok {
		sysCfgDb.SysCfgInsert(enum.AliyunOss(enum.AliyunOssBucketScheme).String(), "", "oss上传方式")
		bucketScheme = ""
	}
	accessKeyID, ok := cfgMap[enum.AliyunOss(enum.AliyunOssAccessKeyID).String()]
	if !ok {
		sysCfgDb.SysCfgInsert(enum.AliyunOss(enum.AliyunOssAccessKeyID).String(), "", "oss访问秘钥id")
		accessKeyID = ""
	}
	accessKeySecret, ok := cfgMap[enum.AliyunOss(enum.AliyunOssAccessKeySecret).String()]
	if !ok {
		sysCfgDb.SysCfgInsert(enum.AliyunOss(enum.AliyunOssAccessKeySecret).String(), "", "oss访问秘钥")
		accessKeySecret = ""
	}
	domain, ok := cfgMap[enum.AliyunOss(enum.AliyunOssDomain).String()]
	if !ok {
		sysCfgDb.SysCfgInsert(enum.AliyunOss(enum.AliyunOssDomain).String(), "", "oss域名")
		domain = ""
	}

	resp := md.GetBasicResp{
		OssEndpoint:        endpoint,
		OssBucketName:      bucketName,
		OssBucketScheme:    bucketScheme,
		OssAccessKeyId:     accessKeyID,
		OssAccessKeySecret: accessKeySecret,
		OssObjectDomain:    domain,
	}

	e.OutSuc(c, resp, nil)
}

// SetBasic
// @Summary      设置中心-对象存储-对象存储设置(更新)
// @Tags         对象存储
// @Description  对象存储设置(更新)
// @Accept       json
// @Produce      json
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @param req body  md.SetBasicReq true "上传需要修改的信息"
// @Success      200   {string}  	 "success"
// @Failure      400   {object}   md.Response              	"具体错误"
// @Router       /api/comm/oss/getOssUrl [get]
func SetBasic(c *gin.Context) {
	var req *md.SetBasicReq
	if err1 := c.ShouldBindJSON(&req); err1 != nil {
		e.OutErr(c, e.ERR_INVALID_ARGS, err1.Error())
		return
	}

	redisConn := cache.GetPool().Get()
	cfgDb := implement.NewSysCfgDb(db.Db, redisConn)

	if req.OssAccessKeyId != "" {
		cfgDb.SysCfgUpdate(enum.AliyunOss(enum.AliyunOssAccessKeyID).String(), req.OssAccessKeyId)
	}
	if req.OssAccessKeySecret != "" {
		cfgDb.SysCfgUpdate(enum.AliyunOss(enum.AliyunOssAccessKeySecret).String(), req.OssAccessKeySecret)
	}
	if req.OssBucketScheme != "" {
		cfgDb.SysCfgUpdate(enum.AliyunOss(enum.AliyunOssBucketScheme).String(), req.OssBucketScheme)
	}
	if req.OssObjectDomain != "" {
		cfgDb.SysCfgUpdate(enum.AliyunOss(enum.AliyunOssDomain).String(), req.OssObjectDomain)
	}
	if req.OssBucketName != "" {
		cfgDb.SysCfgUpdate(enum.AliyunOss(enum.AliyunOssBucketName).String(), req.OssBucketName)
	}
	if req.OssEndpoint != "" {
		cfgDb.SysCfgUpdate(enum.AliyunOss(enum.AliyunOssEndpoint).String(), req.OssEndpoint)
	}
	e.OutSuc(c, "success", nil)
}
